# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FlowLogArgs', 'FlowLog']

@pulumi.input_type
class FlowLogArgs:
    def __init__(__self__, *,
                 cen_id: pulumi.Input[builtins.str],
                 log_store_name: pulumi.Input[builtins.str],
                 project_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 log_format_string: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a FlowLog resource.
        :param pulumi.Input[builtins.str] cen_id: cen id
        :param pulumi.Input[builtins.str] log_store_name: The LogStore that stores the flowlog.
        :param pulumi.Input[builtins.str] project_name: The Project that stores the flowlog.
        :param pulumi.Input[builtins.str] description: The description of the flowlog.
        :param pulumi.Input[builtins.str] flow_log_name: The name of the flowlog.
        :param pulumi.Input[builtins.int] interval: The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: `60` or **600 * *. Default value: **600 * *.
        :param pulumi.Input[builtins.str] log_format_string: Log Format
        :param pulumi.Input[builtins.str] status: The status of the flow log. Valid values:
               - `Active`: started.
               - `InActive`: not started.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_id: Cross-region Connection ID or VBR connection ID.
               
               > **NOTE:**  This parameter is required.
        :param pulumi.Input[builtins.str] transit_router_id: Transit Router ID
        """
        pulumi.set(__self__, "cen_id", cen_id)
        pulumi.set(__self__, "log_store_name", log_store_name)
        pulumi.set(__self__, "project_name", project_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if flow_log_name is not None:
            pulumi.set(__self__, "flow_log_name", flow_log_name)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if log_format_string is not None:
            pulumi.set(__self__, "log_format_string", log_format_string)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_id is not None:
            pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Input[builtins.str]:
        """
        cen id
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="logStoreName")
    def log_store_name(self) -> pulumi.Input[builtins.str]:
        """
        The LogStore that stores the flowlog.
        """
        return pulumi.get(self, "log_store_name")

    @log_store_name.setter
    def log_store_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "log_store_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[builtins.str]:
        """
        The Project that stores the flowlog.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the flowlog.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the flowlog.
        """
        return pulumi.get(self, "flow_log_name")

    @flow_log_name.setter
    def flow_log_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flow_log_name", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: `60` or **600 * *. Default value: **600 * *.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter(name="logFormatString")
    def log_format_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Log Format
        """
        return pulumi.get(self, "log_format_string")

    @log_format_string.setter
    def log_format_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_format_string", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the flow log. Valid values:
        - `Active`: started.
        - `InActive`: not started.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cross-region Connection ID or VBR connection ID.

        > **NOTE:**  This parameter is required.
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @transit_router_attachment_id.setter
    def transit_router_attachment_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_id", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Transit Router ID
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)


@pulumi.input_type
class _FlowLogState:
    def __init__(__self__, *,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 log_format_string: Optional[pulumi.Input[builtins.str]] = None,
                 log_store_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FlowLog resources.
        :param pulumi.Input[builtins.str] cen_id: cen id
        :param pulumi.Input[builtins.str] create_time: CreateTime
        :param pulumi.Input[builtins.str] description: The description of the flowlog.
        :param pulumi.Input[builtins.str] flow_log_name: The name of the flowlog.
        :param pulumi.Input[builtins.int] interval: The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: `60` or **600 * *. Default value: **600 * *.
        :param pulumi.Input[builtins.str] log_format_string: Log Format
        :param pulumi.Input[builtins.str] log_store_name: The LogStore that stores the flowlog.
        :param pulumi.Input[builtins.str] project_name: The Project that stores the flowlog.
        :param pulumi.Input[builtins.str] region_id: region id
        :param pulumi.Input[builtins.str] status: The status of the flow log. Valid values:
               - `Active`: started.
               - `InActive`: not started.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_id: Cross-region Connection ID or VBR connection ID.
               
               > **NOTE:**  This parameter is required.
        :param pulumi.Input[builtins.str] transit_router_id: Transit Router ID
        """
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if flow_log_name is not None:
            pulumi.set(__self__, "flow_log_name", flow_log_name)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if log_format_string is not None:
            pulumi.set(__self__, "log_format_string", log_format_string)
        if log_store_name is not None:
            pulumi.set(__self__, "log_store_name", log_store_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_id is not None:
            pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        cen id
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the flowlog.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the flowlog.
        """
        return pulumi.get(self, "flow_log_name")

    @flow_log_name.setter
    def flow_log_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flow_log_name", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: `60` or **600 * *. Default value: **600 * *.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter(name="logFormatString")
    def log_format_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Log Format
        """
        return pulumi.get(self, "log_format_string")

    @log_format_string.setter
    def log_format_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_format_string", value)

    @property
    @pulumi.getter(name="logStoreName")
    def log_store_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The LogStore that stores the flowlog.
        """
        return pulumi.get(self, "log_store_name")

    @log_store_name.setter
    def log_store_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "log_store_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Project that stores the flowlog.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        region id
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the flow log. Valid values:
        - `Active`: started.
        - `InActive`: not started.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cross-region Connection ID or VBR connection ID.

        > **NOTE:**  This parameter is required.
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @transit_router_attachment_id.setter
    def transit_router_attachment_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_id", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Transit Router ID
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)


@pulumi.type_token("alicloud:cen/flowLog:FlowLog")
class FlowLog(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 log_format_string: Optional[pulumi.Input[builtins.str]] = None,
                 log_store_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a CEN Flow Log resource.

        For information about CEN Flow Log and how to use it, see [What is Flow Log](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-createflowlog).

        > **NOTE:** Available since v1.73.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a cen flowlog resource and use it to publish a route entry pointing to an ECS.
        default = alicloud.cen.Instance("default", name="my-cen")
        default_project = alicloud.log.Project("default",
            name="sls-for-flowlog",
            description="create by terraform")
        default_store = alicloud.log.Store("default",
            project=default_project.name,
            name="sls-for-flowlog",
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        default_flow_log = alicloud.cen.FlowLog("default",
            flow_log_name="my-flowlog",
            cen_id=default.id,
            project_name=default_project.name,
            log_store_name=default_store.name)
        ```

        ## Import

        CEN Flow Log can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/flowLog:FlowLog example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cen_id: cen id
        :param pulumi.Input[builtins.str] description: The description of the flowlog.
        :param pulumi.Input[builtins.str] flow_log_name: The name of the flowlog.
        :param pulumi.Input[builtins.int] interval: The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: `60` or **600 * *. Default value: **600 * *.
        :param pulumi.Input[builtins.str] log_format_string: Log Format
        :param pulumi.Input[builtins.str] log_store_name: The LogStore that stores the flowlog.
        :param pulumi.Input[builtins.str] project_name: The Project that stores the flowlog.
        :param pulumi.Input[builtins.str] status: The status of the flow log. Valid values:
               - `Active`: started.
               - `InActive`: not started.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_id: Cross-region Connection ID or VBR connection ID.
               
               > **NOTE:**  This parameter is required.
        :param pulumi.Input[builtins.str] transit_router_id: Transit Router ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FlowLogArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a CEN Flow Log resource.

        For information about CEN Flow Log and how to use it, see [What is Flow Log](https://www.alibabacloud.com/help/en/cen/developer-reference/api-cbn-2017-09-12-createflowlog).

        > **NOTE:** Available since v1.73.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a cen flowlog resource and use it to publish a route entry pointing to an ECS.
        default = alicloud.cen.Instance("default", name="my-cen")
        default_project = alicloud.log.Project("default",
            name="sls-for-flowlog",
            description="create by terraform")
        default_store = alicloud.log.Store("default",
            project=default_project.name,
            name="sls-for-flowlog",
            retention_period=3650,
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        default_flow_log = alicloud.cen.FlowLog("default",
            flow_log_name="my-flowlog",
            cen_id=default.id,
            project_name=default_project.name,
            log_store_name=default_store.name)
        ```

        ## Import

        CEN Flow Log can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/flowLog:FlowLog example <id>
        ```

        :param str resource_name: The name of the resource.
        :param FlowLogArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FlowLogArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 log_format_string: Optional[pulumi.Input[builtins.str]] = None,
                 log_store_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FlowLogArgs.__new__(FlowLogArgs)

            if cen_id is None and not opts.urn:
                raise TypeError("Missing required property 'cen_id'")
            __props__.__dict__["cen_id"] = cen_id
            __props__.__dict__["description"] = description
            __props__.__dict__["flow_log_name"] = flow_log_name
            __props__.__dict__["interval"] = interval
            __props__.__dict__["log_format_string"] = log_format_string
            if log_store_name is None and not opts.urn:
                raise TypeError("Missing required property 'log_store_name'")
            __props__.__dict__["log_store_name"] = log_store_name
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["status"] = status
            __props__.__dict__["tags"] = tags
            __props__.__dict__["transit_router_attachment_id"] = transit_router_attachment_id
            __props__.__dict__["transit_router_id"] = transit_router_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
        super(FlowLog, __self__).__init__(
            'alicloud:cen/flowLog:FlowLog',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cen_id: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            flow_log_name: Optional[pulumi.Input[builtins.str]] = None,
            interval: Optional[pulumi.Input[builtins.int]] = None,
            log_format_string: Optional[pulumi.Input[builtins.str]] = None,
            log_store_name: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_id: Optional[pulumi.Input[builtins.str]] = None) -> 'FlowLog':
        """
        Get an existing FlowLog resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cen_id: cen id
        :param pulumi.Input[builtins.str] create_time: CreateTime
        :param pulumi.Input[builtins.str] description: The description of the flowlog.
        :param pulumi.Input[builtins.str] flow_log_name: The name of the flowlog.
        :param pulumi.Input[builtins.int] interval: The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: `60` or **600 * *. Default value: **600 * *.
        :param pulumi.Input[builtins.str] log_format_string: Log Format
        :param pulumi.Input[builtins.str] log_store_name: The LogStore that stores the flowlog.
        :param pulumi.Input[builtins.str] project_name: The Project that stores the flowlog.
        :param pulumi.Input[builtins.str] region_id: region id
        :param pulumi.Input[builtins.str] status: The status of the flow log. Valid values:
               - `Active`: started.
               - `InActive`: not started.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transit_router_attachment_id: Cross-region Connection ID or VBR connection ID.
               
               > **NOTE:**  This parameter is required.
        :param pulumi.Input[builtins.str] transit_router_id: Transit Router ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FlowLogState.__new__(_FlowLogState)

        __props__.__dict__["cen_id"] = cen_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["flow_log_name"] = flow_log_name
        __props__.__dict__["interval"] = interval
        __props__.__dict__["log_format_string"] = log_format_string
        __props__.__dict__["log_store_name"] = log_store_name
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transit_router_attachment_id"] = transit_router_attachment_id
        __props__.__dict__["transit_router_id"] = transit_router_id
        return FlowLog(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Output[builtins.str]:
        """
        cen id
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the flowlog.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the flowlog.
        """
        return pulumi.get(self, "flow_log_name")

    @property
    @pulumi.getter
    def interval(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: `60` or **600 * *. Default value: **600 * *.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="logFormatString")
    def log_format_string(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Log Format
        """
        return pulumi.get(self, "log_format_string")

    @property
    @pulumi.getter(name="logStoreName")
    def log_store_name(self) -> pulumi.Output[builtins.str]:
        """
        The LogStore that stores the flowlog.
        """
        return pulumi.get(self, "log_store_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        The Project that stores the flowlog.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        region id
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the flow log. Valid values:
        - `Active`: started.
        - `InActive`: not started.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Cross-region Connection ID or VBR connection ID.

        > **NOTE:**  This parameter is required.
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Transit Router ID
        """
        return pulumi.get(self, "transit_router_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServerGroupArgs', 'ServerGroup']

@pulumi.input_type
class ServerGroupArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[builtins.str],
                 connection_drain_config: Optional[pulumi.Input['ServerGroupConnectionDrainConfigArgs']] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 health_check_config: Optional[pulumi.Input['ServerGroupHealthCheckConfigArgs']] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a ServerGroup resource.
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
               
               > **NOTE:**  If `ServerGroupType` is set to `Instance`, only servers in the specified VPC can be added to the server group.
        :param pulumi.Input['ServerGroupConnectionDrainConfigArgs'] connection_drain_config: Connected graceful interrupt configuration. See `connection_drain_config` below.
        :param pulumi.Input[builtins.bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input['ServerGroupHealthCheckConfigArgs'] health_check_config: Health check configurations. See `health_check_config` below.
        :param pulumi.Input[builtins.str] protocol: The backend protocol. Valid values:
               
               - `GENEVE`(default)
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] scheduler: The scheduling algorithm. Valid values:
               
               - `5TCH` (default): specifies consistent hashing that is based on the following factors: source IP address, destination IP address, source port, protocol, and destination port. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `3TCH`: specifies consistent hashing that is based on the following factors: source IP address, destination IP address, and protocol. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `2TCH`: specifies consistent hashing that is based on the following factors: source IP address and destination IP address. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        :param pulumi.Input[builtins.str] server_group_name: The server group name.
               
               The name must be 2 to 128 characters in length, and can contain digits, periods (.), underscores (\\_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[builtins.str] server_group_type: The type of server group. Valid values:
               
               - `Instance` (default): allows you to specify servers of the `Ecs`, `Eni`, or `Eci` type.
               - `Ip`: allows you to add servers of by specifying IP addresses.
        :param pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]] servers: The backend servers that you want to remove.
               
               > **NOTE:**  You can remove at most 200 backend servers in each call.
               See `servers` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag keys.
               
               You can specify at most 20 tags in each call.
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if connection_drain_config is not None:
            pulumi.set(__self__, "connection_drain_config", connection_drain_config)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if health_check_config is not None:
            pulumi.set(__self__, "health_check_config", health_check_config)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if scheduler is not None:
            pulumi.set(__self__, "scheduler", scheduler)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if server_group_type is not None:
            pulumi.set(__self__, "server_group_type", server_group_type)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        The VPC ID.

        > **NOTE:**  If `ServerGroupType` is set to `Instance`, only servers in the specified VPC can be added to the server group.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="connectionDrainConfig")
    def connection_drain_config(self) -> Optional[pulumi.Input['ServerGroupConnectionDrainConfigArgs']]:
        """
        Connected graceful interrupt configuration. See `connection_drain_config` below.
        """
        return pulumi.get(self, "connection_drain_config")

    @connection_drain_config.setter
    def connection_drain_config(self, value: Optional[pulumi.Input['ServerGroupConnectionDrainConfigArgs']]):
        pulumi.set(self, "connection_drain_config", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="healthCheckConfig")
    def health_check_config(self) -> Optional[pulumi.Input['ServerGroupHealthCheckConfigArgs']]:
        """
        Health check configurations. See `health_check_config` below.
        """
        return pulumi.get(self, "health_check_config")

    @health_check_config.setter
    def health_check_config(self, value: Optional[pulumi.Input['ServerGroupHealthCheckConfigArgs']]):
        pulumi.set(self, "health_check_config", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The backend protocol. Valid values:

        - `GENEVE`(default)
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def scheduler(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The scheduling algorithm. Valid values:

        - `5TCH` (default): specifies consistent hashing that is based on the following factors: source IP address, destination IP address, source port, protocol, and destination port. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        - `3TCH`: specifies consistent hashing that is based on the following factors: source IP address, destination IP address, and protocol. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        - `2TCH`: specifies consistent hashing that is based on the following factors: source IP address and destination IP address. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        """
        return pulumi.get(self, "scheduler")

    @scheduler.setter
    def scheduler(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduler", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The server group name.

        The name must be 2 to 128 characters in length, and can contain digits, periods (.), underscores (\\_), and hyphens (-). It must start with a letter.
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter(name="serverGroupType")
    def server_group_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of server group. Valid values:

        - `Instance` (default): allows you to specify servers of the `Ecs`, `Eni`, or `Eci` type.
        - `Ip`: allows you to add servers of by specifying IP addresses.
        """
        return pulumi.get(self, "server_group_type")

    @server_group_type.setter
    def server_group_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_type", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]:
        """
        The backend servers that you want to remove.

        > **NOTE:**  You can remove at most 200 backend servers in each call.
        See `servers` below.
        """
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag keys.

        You can specify at most 20 tags in each call.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ServerGroupState:
    def __init__(__self__, *,
                 connection_drain_config: Optional[pulumi.Input['ServerGroupConnectionDrainConfigArgs']] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 health_check_config: Optional[pulumi.Input['ServerGroupHealthCheckConfigArgs']] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServerGroup resources.
        :param pulumi.Input['ServerGroupConnectionDrainConfigArgs'] connection_drain_config: Connected graceful interrupt configuration. See `connection_drain_config` below.
        :param pulumi.Input[builtins.str] create_time: The time when the resource was created. The time follows the ISO 8601 standard in the **yyyy-MM-ddTHH:mm:ssZ** format. The time is displayed in UTC.
        :param pulumi.Input[builtins.bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input['ServerGroupHealthCheckConfigArgs'] health_check_config: Health check configurations. See `health_check_config` below.
        :param pulumi.Input[builtins.str] protocol: The backend protocol. Valid values:
               
               - `GENEVE`(default)
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] scheduler: The scheduling algorithm. Valid values:
               
               - `5TCH` (default): specifies consistent hashing that is based on the following factors: source IP address, destination IP address, source port, protocol, and destination port. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `3TCH`: specifies consistent hashing that is based on the following factors: source IP address, destination IP address, and protocol. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `2TCH`: specifies consistent hashing that is based on the following factors: source IP address and destination IP address. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        :param pulumi.Input[builtins.str] server_group_name: The server group name.
               
               The name must be 2 to 128 characters in length, and can contain digits, periods (.), underscores (\\_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[builtins.str] server_group_type: The type of server group. Valid values:
               
               - `Instance` (default): allows you to specify servers of the `Ecs`, `Eni`, or `Eci` type.
               - `Ip`: allows you to add servers of by specifying IP addresses.
        :param pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]] servers: The backend servers that you want to remove.
               
               > **NOTE:**  You can remove at most 200 backend servers in each call.
               See `servers` below.
        :param pulumi.Input[builtins.str] status: Indicates the status of the backend server.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag keys.
               
               You can specify at most 20 tags in each call.
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
               
               > **NOTE:**  If `ServerGroupType` is set to `Instance`, only servers in the specified VPC can be added to the server group.
        """
        if connection_drain_config is not None:
            pulumi.set(__self__, "connection_drain_config", connection_drain_config)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if health_check_config is not None:
            pulumi.set(__self__, "health_check_config", health_check_config)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if scheduler is not None:
            pulumi.set(__self__, "scheduler", scheduler)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if server_group_type is not None:
            pulumi.set(__self__, "server_group_type", server_group_type)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="connectionDrainConfig")
    def connection_drain_config(self) -> Optional[pulumi.Input['ServerGroupConnectionDrainConfigArgs']]:
        """
        Connected graceful interrupt configuration. See `connection_drain_config` below.
        """
        return pulumi.get(self, "connection_drain_config")

    @connection_drain_config.setter
    def connection_drain_config(self, value: Optional[pulumi.Input['ServerGroupConnectionDrainConfigArgs']]):
        pulumi.set(self, "connection_drain_config", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the resource was created. The time follows the ISO 8601 standard in the **yyyy-MM-ddTHH:mm:ssZ** format. The time is displayed in UTC.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="healthCheckConfig")
    def health_check_config(self) -> Optional[pulumi.Input['ServerGroupHealthCheckConfigArgs']]:
        """
        Health check configurations. See `health_check_config` below.
        """
        return pulumi.get(self, "health_check_config")

    @health_check_config.setter
    def health_check_config(self, value: Optional[pulumi.Input['ServerGroupHealthCheckConfigArgs']]):
        pulumi.set(self, "health_check_config", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The backend protocol. Valid values:

        - `GENEVE`(default)
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def scheduler(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The scheduling algorithm. Valid values:

        - `5TCH` (default): specifies consistent hashing that is based on the following factors: source IP address, destination IP address, source port, protocol, and destination port. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        - `3TCH`: specifies consistent hashing that is based on the following factors: source IP address, destination IP address, and protocol. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        - `2TCH`: specifies consistent hashing that is based on the following factors: source IP address and destination IP address. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        """
        return pulumi.get(self, "scheduler")

    @scheduler.setter
    def scheduler(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduler", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The server group name.

        The name must be 2 to 128 characters in length, and can contain digits, periods (.), underscores (\\_), and hyphens (-). It must start with a letter.
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter(name="serverGroupType")
    def server_group_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of server group. Valid values:

        - `Instance` (default): allows you to specify servers of the `Ecs`, `Eni`, or `Eci` type.
        - `Ip`: allows you to add servers of by specifying IP addresses.
        """
        return pulumi.get(self, "server_group_type")

    @server_group_type.setter
    def server_group_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_type", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]:
        """
        The backend servers that you want to remove.

        > **NOTE:**  You can remove at most 200 backend servers in each call.
        See `servers` below.
        """
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates the status of the backend server.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag keys.

        You can specify at most 20 tags in each call.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The VPC ID.

        > **NOTE:**  If `ServerGroupType` is set to `Instance`, only servers in the specified VPC can be added to the server group.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("alicloud:gwlb/serverGroup:ServerGroup")
class ServerGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_drain_config: Optional[pulumi.Input[Union['ServerGroupConnectionDrainConfigArgs', 'ServerGroupConnectionDrainConfigArgsDict']]] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 health_check_config: Optional[pulumi.Input[Union['ServerGroupHealthCheckConfigArgs', 'ServerGroupHealthCheckConfigArgsDict']]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a GWLB Server Group resource.

        For information about GWLB Server Group and how to use it, see [What is Server Group](https://www.alibabacloud.com/help/en/slb/gateway-based-load-balancing-gwlb/developer-reference/api-gwlb-2024-04-15-createservergroup).

        > **NOTE:** Available since v1.234.0.

        ## Import

        GWLB Server Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gwlb/serverGroup:ServerGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ServerGroupConnectionDrainConfigArgs', 'ServerGroupConnectionDrainConfigArgsDict']] connection_drain_config: Connected graceful interrupt configuration. See `connection_drain_config` below.
        :param pulumi.Input[builtins.bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[Union['ServerGroupHealthCheckConfigArgs', 'ServerGroupHealthCheckConfigArgsDict']] health_check_config: Health check configurations. See `health_check_config` below.
        :param pulumi.Input[builtins.str] protocol: The backend protocol. Valid values:
               
               - `GENEVE`(default)
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] scheduler: The scheduling algorithm. Valid values:
               
               - `5TCH` (default): specifies consistent hashing that is based on the following factors: source IP address, destination IP address, source port, protocol, and destination port. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `3TCH`: specifies consistent hashing that is based on the following factors: source IP address, destination IP address, and protocol. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `2TCH`: specifies consistent hashing that is based on the following factors: source IP address and destination IP address. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        :param pulumi.Input[builtins.str] server_group_name: The server group name.
               
               The name must be 2 to 128 characters in length, and can contain digits, periods (.), underscores (\\_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[builtins.str] server_group_type: The type of server group. Valid values:
               
               - `Instance` (default): allows you to specify servers of the `Ecs`, `Eni`, or `Eci` type.
               - `Ip`: allows you to add servers of by specifying IP addresses.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]] servers: The backend servers that you want to remove.
               
               > **NOTE:**  You can remove at most 200 backend servers in each call.
               See `servers` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag keys.
               
               You can specify at most 20 tags in each call.
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
               
               > **NOTE:**  If `ServerGroupType` is set to `Instance`, only servers in the specified VPC can be added to the server group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GWLB Server Group resource.

        For information about GWLB Server Group and how to use it, see [What is Server Group](https://www.alibabacloud.com/help/en/slb/gateway-based-load-balancing-gwlb/developer-reference/api-gwlb-2024-04-15-createservergroup).

        > **NOTE:** Available since v1.234.0.

        ## Import

        GWLB Server Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gwlb/serverGroup:ServerGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ServerGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_drain_config: Optional[pulumi.Input[Union['ServerGroupConnectionDrainConfigArgs', 'ServerGroupConnectionDrainConfigArgsDict']]] = None,
                 dry_run: Optional[pulumi.Input[builtins.bool]] = None,
                 health_check_config: Optional[pulumi.Input[Union['ServerGroupHealthCheckConfigArgs', 'ServerGroupHealthCheckConfigArgsDict']]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerGroupArgs.__new__(ServerGroupArgs)

            __props__.__dict__["connection_drain_config"] = connection_drain_config
            __props__.__dict__["dry_run"] = dry_run
            __props__.__dict__["health_check_config"] = health_check_config
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["scheduler"] = scheduler
            __props__.__dict__["server_group_name"] = server_group_name
            __props__.__dict__["server_group_type"] = server_group_type
            __props__.__dict__["servers"] = servers
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(ServerGroup, __self__).__init__(
            'alicloud:gwlb/serverGroup:ServerGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connection_drain_config: Optional[pulumi.Input[Union['ServerGroupConnectionDrainConfigArgs', 'ServerGroupConnectionDrainConfigArgsDict']]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            dry_run: Optional[pulumi.Input[builtins.bool]] = None,
            health_check_config: Optional[pulumi.Input[Union['ServerGroupHealthCheckConfigArgs', 'ServerGroupHealthCheckConfigArgsDict']]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            scheduler: Optional[pulumi.Input[builtins.str]] = None,
            server_group_name: Optional[pulumi.Input[builtins.str]] = None,
            server_group_type: Optional[pulumi.Input[builtins.str]] = None,
            servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'ServerGroup':
        """
        Get an existing ServerGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ServerGroupConnectionDrainConfigArgs', 'ServerGroupConnectionDrainConfigArgsDict']] connection_drain_config: Connected graceful interrupt configuration. See `connection_drain_config` below.
        :param pulumi.Input[builtins.str] create_time: The time when the resource was created. The time follows the ISO 8601 standard in the **yyyy-MM-ddTHH:mm:ssZ** format. The time is displayed in UTC.
        :param pulumi.Input[builtins.bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        :param pulumi.Input[Union['ServerGroupHealthCheckConfigArgs', 'ServerGroupHealthCheckConfigArgsDict']] health_check_config: Health check configurations. See `health_check_config` below.
        :param pulumi.Input[builtins.str] protocol: The backend protocol. Valid values:
               
               - `GENEVE`(default)
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] scheduler: The scheduling algorithm. Valid values:
               
               - `5TCH` (default): specifies consistent hashing that is based on the following factors: source IP address, destination IP address, source port, protocol, and destination port. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `3TCH`: specifies consistent hashing that is based on the following factors: source IP address, destination IP address, and protocol. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
               - `2TCH`: specifies consistent hashing that is based on the following factors: source IP address and destination IP address. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        :param pulumi.Input[builtins.str] server_group_name: The server group name.
               
               The name must be 2 to 128 characters in length, and can contain digits, periods (.), underscores (\\_), and hyphens (-). It must start with a letter.
        :param pulumi.Input[builtins.str] server_group_type: The type of server group. Valid values:
               
               - `Instance` (default): allows you to specify servers of the `Ecs`, `Eni`, or `Eci` type.
               - `Ip`: allows you to add servers of by specifying IP addresses.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]] servers: The backend servers that you want to remove.
               
               > **NOTE:**  You can remove at most 200 backend servers in each call.
               See `servers` below.
        :param pulumi.Input[builtins.str] status: Indicates the status of the backend server.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag keys.
               
               You can specify at most 20 tags in each call.
        :param pulumi.Input[builtins.str] vpc_id: The VPC ID.
               
               > **NOTE:**  If `ServerGroupType` is set to `Instance`, only servers in the specified VPC can be added to the server group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerGroupState.__new__(_ServerGroupState)

        __props__.__dict__["connection_drain_config"] = connection_drain_config
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["health_check_config"] = health_check_config
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["scheduler"] = scheduler
        __props__.__dict__["server_group_name"] = server_group_name
        __props__.__dict__["server_group_type"] = server_group_type
        __props__.__dict__["servers"] = servers
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc_id"] = vpc_id
        return ServerGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectionDrainConfig")
    def connection_drain_config(self) -> pulumi.Output['outputs.ServerGroupConnectionDrainConfig']:
        """
        Connected graceful interrupt configuration. See `connection_drain_config` below.
        """
        return pulumi.get(self, "connection_drain_config")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the resource was created. The time follows the ISO 8601 standard in the **yyyy-MM-ddTHH:mm:ssZ** format. The time is displayed in UTC.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="healthCheckConfig")
    def health_check_config(self) -> pulumi.Output['outputs.ServerGroupHealthCheckConfig']:
        """
        Health check configurations. See `health_check_config` below.
        """
        return pulumi.get(self, "health_check_config")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        The backend protocol. Valid values:

        - `GENEVE`(default)
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def scheduler(self) -> pulumi.Output[builtins.str]:
        """
        The scheduling algorithm. Valid values:

        - `5TCH` (default): specifies consistent hashing that is based on the following factors: source IP address, destination IP address, source port, protocol, and destination port. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        - `3TCH`: specifies consistent hashing that is based on the following factors: source IP address, destination IP address, and protocol. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        - `2TCH`: specifies consistent hashing that is based on the following factors: source IP address and destination IP address. Requests that contain the same information based on the preceding factors are forwarded to the same backend server.
        """
        return pulumi.get(self, "scheduler")

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The server group name.

        The name must be 2 to 128 characters in length, and can contain digits, periods (.), underscores (\\_), and hyphens (-). It must start with a letter.
        """
        return pulumi.get(self, "server_group_name")

    @property
    @pulumi.getter(name="serverGroupType")
    def server_group_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of server group. Valid values:

        - `Instance` (default): allows you to specify servers of the `Ecs`, `Eni`, or `Eci` type.
        - `Ip`: allows you to add servers of by specifying IP addresses.
        """
        return pulumi.get(self, "server_group_type")

    @property
    @pulumi.getter
    def servers(self) -> pulumi.Output[Optional[Sequence['outputs.ServerGroupServer']]]:
        """
        The backend servers that you want to remove.

        > **NOTE:**  You can remove at most 200 backend servers in each call.
        See `servers` below.
        """
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Indicates the status of the backend server.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag keys.

        You can specify at most 20 tags in each call.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        The VPC ID.

        > **NOTE:**  If `ServerGroupType` is set to `Instance`, only servers in the specified VPC can be added to the server group.
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NetworkArgs', 'Network']

@pulumi.input_type
class NetworkArgs:
    def __init__(__self__, *,
                 dw_resource_group_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 vswitch_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a Network resource.
        :param pulumi.Input[builtins.str] dw_resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] vpc_id: Virtual Private Cloud ID of network resources
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID of the network resource.
        """
        pulumi.set(__self__, "dw_resource_group_id", dw_resource_group_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="dwResourceGroupId")
    def dw_resource_group_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "dw_resource_group_id")

    @dw_resource_group_id.setter
    def dw_resource_group_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "dw_resource_group_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        Virtual Private Cloud ID of network resources
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[builtins.str]:
        """
        The vSwitch ID of the network resource.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vswitch_id", value)


@pulumi.input_type
class _NetworkState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.int]] = None,
                 dw_resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Network resources.
        :param pulumi.Input[builtins.int] create_time: Time when the network resource was created
        :param pulumi.Input[builtins.str] dw_resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] status: Network Resource Status
        :param pulumi.Input[builtins.str] vpc_id: Virtual Private Cloud ID of network resources
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID of the network resource.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if dw_resource_group_id is not None:
            pulumi.set(__self__, "dw_resource_group_id", dw_resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Time when the network resource was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dwResourceGroupId")
    def dw_resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "dw_resource_group_id")

    @dw_resource_group_id.setter
    def dw_resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dw_resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Network Resource Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Virtual Private Cloud ID of network resources
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The vSwitch ID of the network resource.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)


@pulumi.type_token("alicloud:dataworks/network:Network")
class Network(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dw_resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Data Works Network resource.

        Resource Group Network.

        For information about Data Works Network and how to use it, see [What is Network](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createnetwork).

        > **NOTE:** Available since v1.241.0.

        ## Import

        Data Works Network can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/network:Network example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] dw_resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] vpc_id: Virtual Private Cloud ID of network resources
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID of the network resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Network resource.

        Resource Group Network.

        For information about Data Works Network and how to use it, see [What is Network](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createnetwork).

        > **NOTE:** Available since v1.241.0.

        ## Import

        Data Works Network can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/network:Network example <id>
        ```

        :param str resource_name: The name of the resource.
        :param NetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dw_resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkArgs.__new__(NetworkArgs)

            if dw_resource_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'dw_resource_group_id'")
            __props__.__dict__["dw_resource_group_id"] = dw_resource_group_id
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_id'")
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Network, __self__).__init__(
            'alicloud:dataworks/network:Network',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.int]] = None,
            dw_resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vswitch_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Network':
        """
        Get an existing Network resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] create_time: Time when the network resource was created
        :param pulumi.Input[builtins.str] dw_resource_group_id: The ID of the resource group.
        :param pulumi.Input[builtins.str] status: Network Resource Status
        :param pulumi.Input[builtins.str] vpc_id: Virtual Private Cloud ID of network resources
        :param pulumi.Input[builtins.str] vswitch_id: The vSwitch ID of the network resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkState.__new__(_NetworkState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["dw_resource_group_id"] = dw_resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        return Network(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.int]:
        """
        Time when the network resource was created
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dwResourceGroupId")
    def dw_resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "dw_resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Network Resource Status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        Virtual Private Cloud ID of network resources
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[builtins.str]:
        """
        The vSwitch ID of the network resource.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpcCenTrFirewallsResult',
    'AwaitableGetVpcCenTrFirewallsResult',
    'get_vpc_cen_tr_firewalls',
    'get_vpc_cen_tr_firewalls_output',
]

@pulumi.output_type
class GetVpcCenTrFirewallsResult:
    """
    A collection of values returned by getVpcCenTrFirewalls.
    """
    def __init__(__self__, cen_id=None, current_page=None, firewall_id=None, firewall_name=None, firewall_switch_status=None, firewalls=None, id=None, ids=None, output_file=None, page_number=None, page_size=None, region_no=None, route_mode=None, transit_router_id=None):
        if cen_id and not isinstance(cen_id, str):
            raise TypeError("Expected argument 'cen_id' to be a str")
        pulumi.set(__self__, "cen_id", cen_id)
        if current_page and not isinstance(current_page, int):
            raise TypeError("Expected argument 'current_page' to be a int")
        pulumi.set(__self__, "current_page", current_page)
        if firewall_id and not isinstance(firewall_id, str):
            raise TypeError("Expected argument 'firewall_id' to be a str")
        pulumi.set(__self__, "firewall_id", firewall_id)
        if firewall_name and not isinstance(firewall_name, str):
            raise TypeError("Expected argument 'firewall_name' to be a str")
        pulumi.set(__self__, "firewall_name", firewall_name)
        if firewall_switch_status and not isinstance(firewall_switch_status, str):
            raise TypeError("Expected argument 'firewall_switch_status' to be a str")
        pulumi.set(__self__, "firewall_switch_status", firewall_switch_status)
        if firewalls and not isinstance(firewalls, list):
            raise TypeError("Expected argument 'firewalls' to be a list")
        pulumi.set(__self__, "firewalls", firewalls)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if region_no and not isinstance(region_no, str):
            raise TypeError("Expected argument 'region_no' to be a str")
        pulumi.set(__self__, "region_no", region_no)
        if route_mode and not isinstance(route_mode, str):
            raise TypeError("Expected argument 'route_mode' to be a str")
        pulumi.set(__self__, "route_mode", route_mode)
        if transit_router_id and not isinstance(transit_router_id, str):
            raise TypeError("Expected argument 'transit_router_id' to be a str")
        pulumi.set(__self__, "transit_router_id", transit_router_id)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[builtins.str]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="currentPage")
    def current_page(self) -> Optional[builtins.int]:
        return pulumi.get(self, "current_page")

    @property
    @pulumi.getter(name="firewallId")
    def firewall_id(self) -> Optional[builtins.str]:
        """
        Firewall ID
        """
        return pulumi.get(self, "firewall_id")

    @property
    @pulumi.getter(name="firewallName")
    def firewall_name(self) -> Optional[builtins.str]:
        """
        The name of Cloud Firewall.
        """
        return pulumi.get(self, "firewall_name")

    @property
    @pulumi.getter(name="firewallSwitchStatus")
    def firewall_switch_status(self) -> Optional[builtins.str]:
        """
        The status of the VPC boundary firewall. Value:-**opened**: opened-**closed**: closed-**notconfigured**: indicates that the VPC boundary firewall has not been configured yet.-**configured**: indicates that the VPC boundary firewall has been configured.-**creating**: indicates that a VPC boundary firewall is being created.-**opening**: indicates that the VPC border firewall is being enabled.-**deleting**: indicates that the VPC boundary firewall is being deleted.> If this parameter is not set, the VPC boundary firewall in all states is queried.
        """
        return pulumi.get(self, "firewall_switch_status")

    @property
    @pulumi.getter
    def firewalls(self) -> Sequence['outputs.GetVpcCenTrFirewallsFirewallResult']:
        """
        A list of Vpc Cen Tr Firewall Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "firewalls")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Vpc Cen Tr Firewall IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> Optional[builtins.str]:
        """
        The region ID of the transit router instance.
        """
        return pulumi.get(self, "region_no")

    @property
    @pulumi.getter(name="routeMode")
    def route_mode(self) -> Optional[builtins.str]:
        """
        The routing pattern. Value: managed: indicates automatic mode
        """
        return pulumi.get(self, "route_mode")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[builtins.str]:
        """
        The ID of the transit router instance.
        """
        return pulumi.get(self, "transit_router_id")


class AwaitableGetVpcCenTrFirewallsResult(GetVpcCenTrFirewallsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcCenTrFirewallsResult(
            cen_id=self.cen_id,
            current_page=self.current_page,
            firewall_id=self.firewall_id,
            firewall_name=self.firewall_name,
            firewall_switch_status=self.firewall_switch_status,
            firewalls=self.firewalls,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            region_no=self.region_no,
            route_mode=self.route_mode,
            transit_router_id=self.transit_router_id)


def get_vpc_cen_tr_firewalls(cen_id: Optional[builtins.str] = None,
                             current_page: Optional[builtins.int] = None,
                             firewall_id: Optional[builtins.str] = None,
                             firewall_name: Optional[builtins.str] = None,
                             firewall_switch_status: Optional[builtins.str] = None,
                             ids: Optional[Sequence[builtins.str]] = None,
                             output_file: Optional[builtins.str] = None,
                             page_number: Optional[builtins.int] = None,
                             page_size: Optional[builtins.int] = None,
                             region_no: Optional[builtins.str] = None,
                             route_mode: Optional[builtins.str] = None,
                             transit_router_id: Optional[builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpcCenTrFirewallsResult:
    """
    This data source provides Cloud Firewall Vpc Cen Tr Firewall available to the user.[What is Vpc Cen Tr Firewall](https://next.api.alibabacloud.com/document/Cloudfw/2017-12-07/CreateTrFirewallV2)

    > **NOTE:** Available since v1.243.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    description = config.get("description")
    if description is None:
        description = "Created by Terraform"
    firewall_name = config.get("firewallName")
    if firewall_name is None:
        firewall_name = "tf-example"
    tr_attachment_master_cidr = config.get("trAttachmentMasterCidr")
    if tr_attachment_master_cidr is None:
        tr_attachment_master_cidr = "192.168.3.192/26"
    firewall_subnet_cidr = config.get("firewallSubnetCidr")
    if firewall_subnet_cidr is None:
        firewall_subnet_cidr = "192.168.3.0/25"
    region = config.get("region")
    if region is None:
        region = "cn-hangzhou"
    tr_attachment_slave_cidr = config.get("trAttachmentSlaveCidr")
    if tr_attachment_slave_cidr is None:
        tr_attachment_slave_cidr = "192.168.3.128/26"
    firewall_vpc_cidr = config.get("firewallVpcCidr")
    if firewall_vpc_cidr is None:
        firewall_vpc_cidr = "192.168.3.0/24"
    zone1 = config.get("zone1")
    if zone1 is None:
        zone1 = "cn-hangzhou-h"
    firewall_name_update = config.get("firewallNameUpdate")
    if firewall_name_update is None:
        firewall_name_update = "tf-example-1"
    zone2 = config.get("zone2")
    if zone2 is None:
        zone2 = "cn-hangzhou-i"
    cen = alicloud.cen.Instance("cen",
        description="terraform example",
        cen_instance_name="Cen_Terraform_example01")
    tr = alicloud.cen.TransitRouter("tr",
        support_multicast=False,
        transit_router_name="CEN_TR_Terraform",
        transit_router_description="tr-created-by-terraform",
        cen_id=cen.id)
    vpc1 = alicloud.vpc.Network("vpc1",
        description="created by terraform",
        cidr_block="192.168.1.0/24",
        vpc_name="vpc1-Terraform")
    vpc1vsw1 = alicloud.vpc.Switch("vpc1vsw1",
        cidr_block="192.168.1.0/25",
        vswitch_name="vpc1-vsw1",
        vpc_id=vpc1.id,
        zone_id=zone1)
    vpc1vsw2 = alicloud.vpc.Switch("vpc1vsw2",
        vpc_id=vpc1.id,
        cidr_block="192.168.1.128/26",
        vswitch_name="vpc1-vsw2",
        zone_id=zone2)
    vpc2 = alicloud.vpc.Network("vpc2",
        description="created by terraform",
        cidr_block="192.168.2.0/24",
        vpc_name="vpc2-Terraform")
    vpc2vsw1 = alicloud.vpc.Switch("vpc2vsw1",
        cidr_block="192.168.2.0/25",
        vswitch_name="vpc2-vsw1",
        vpc_id=vpc2.id,
        zone_id=zone1)
    vpc2vsw2 = alicloud.vpc.Switch("vpc2vsw2",
        cidr_block="192.168.2.128/26",
        vswitch_name="vpc2-vsw2",
        vpc_id=vpc2.id,
        zone_id=zone2)
    tr_vpc1 = alicloud.cen.TransitRouterVpcAttachment("tr-vpc1",
        auto_publish_route_enabled=False,
        zone_mappings=[
            {
                "vswitch_id": vpc1vsw1.id,
                "zone_id": vpc1vsw1.zone_id,
            },
            {
                "zone_id": vpc1vsw2.zone_id,
                "vswitch_id": vpc1vsw2.id,
            },
        ],
        vpc_id=vpc1.id,
        cen_id=cen.id)
    tr_vpc2 = alicloud.cen.TransitRouterVpcAttachment("tr-vpc2",
        auto_publish_route_enabled=False,
        vpc_id=vpc2.id,
        zone_mappings=[
            {
                "vswitch_id": vpc2vsw1.id,
                "zone_id": vpc2vsw1.zone_id,
            },
            {
                "vswitch_id": vpc2vsw2.id,
                "zone_id": vpc2vsw2.zone_id,
            },
        ],
        cen_id=cen.id)
    default_vpc_cen_tr_firewall = alicloud.cloudfirewall.VpcCenTrFirewall("default",
        firewall_description="VpcCenTrFirewall created by terraform",
        region_no=region,
        route_mode="managed",
        cen_id=cen.id,
        firewall_vpc_cidr=firewall_vpc_cidr,
        transit_router_id=tr.transit_router_id,
        tr_attachment_master_cidr=tr_attachment_master_cidr,
        firewall_name=firewall_name,
        firewall_subnet_cidr=firewall_subnet_cidr,
        tr_attachment_slave_cidr=tr_attachment_slave_cidr)
    default = alicloud.cloudfirewall.get_vpc_cen_tr_firewalls_output(ids=[default_vpc_cen_tr_firewall.id],
        cen_id=cen.id,
        firewall_name=firewall_name,
        region_no=region,
        route_mode="managed",
        transit_router_id=tr.transit_router_id)
    pulumi.export("alicloudCloudFirewallVpcCenTrFirewallExampleId", default.firewalls[0].id)
    ```


    :param builtins.str cen_id: The ID of the CEN instance.
    :param builtins.int current_page: The page number of the pagination query. The default value is 1.
    :param builtins.str firewall_id: Firewall ID
    :param builtins.str firewall_name: The name of Cloud Firewall.
    :param builtins.str firewall_switch_status: The status of the VPC boundary firewall. Value:-**opened**: opened-**closed**: closed-**notconfigured**: indicates that the VPC boundary firewall has not been configured yet.-**configured**: indicates that the VPC boundary firewall has been configured.-**creating**: indicates that a VPC boundary firewall is being created.-**opening**: indicates that the VPC border firewall is being enabled.-**deleting**: indicates that the VPC boundary firewall is being deleted.> If this parameter is not set, the VPC boundary firewall in all states is queried.
    :param Sequence[builtins.str] ids: A list of Vpc Cen Tr Firewall IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Current page number.
    :param builtins.int page_size: The maximum number of pieces of data per page that are displayed during a paged query. The default value is 10.
    :param builtins.str region_no: The region ID of the transit router instance.
    :param builtins.str route_mode: The routing pattern. Value: managed: indicates automatic mode
    :param builtins.str transit_router_id: The ID of the transit router instance.
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['currentPage'] = current_page
    __args__['firewallId'] = firewall_id
    __args__['firewallName'] = firewall_name
    __args__['firewallSwitchStatus'] = firewall_switch_status
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['regionNo'] = region_no
    __args__['routeMode'] = route_mode
    __args__['transitRouterId'] = transit_router_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cloudfirewall/getVpcCenTrFirewalls:getVpcCenTrFirewalls', __args__, opts=opts, typ=GetVpcCenTrFirewallsResult).value

    return AwaitableGetVpcCenTrFirewallsResult(
        cen_id=pulumi.get(__ret__, 'cen_id'),
        current_page=pulumi.get(__ret__, 'current_page'),
        firewall_id=pulumi.get(__ret__, 'firewall_id'),
        firewall_name=pulumi.get(__ret__, 'firewall_name'),
        firewall_switch_status=pulumi.get(__ret__, 'firewall_switch_status'),
        firewalls=pulumi.get(__ret__, 'firewalls'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        region_no=pulumi.get(__ret__, 'region_no'),
        route_mode=pulumi.get(__ret__, 'route_mode'),
        transit_router_id=pulumi.get(__ret__, 'transit_router_id'))
def get_vpc_cen_tr_firewalls_output(cen_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    current_page: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                    firewall_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    firewall_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    firewall_switch_status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                    output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    page_number: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                    page_size: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                    region_no: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    route_mode: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    transit_router_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpcCenTrFirewallsResult]:
    """
    This data source provides Cloud Firewall Vpc Cen Tr Firewall available to the user.[What is Vpc Cen Tr Firewall](https://next.api.alibabacloud.com/document/Cloudfw/2017-12-07/CreateTrFirewallV2)

    > **NOTE:** Available since v1.243.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    description = config.get("description")
    if description is None:
        description = "Created by Terraform"
    firewall_name = config.get("firewallName")
    if firewall_name is None:
        firewall_name = "tf-example"
    tr_attachment_master_cidr = config.get("trAttachmentMasterCidr")
    if tr_attachment_master_cidr is None:
        tr_attachment_master_cidr = "192.168.3.192/26"
    firewall_subnet_cidr = config.get("firewallSubnetCidr")
    if firewall_subnet_cidr is None:
        firewall_subnet_cidr = "192.168.3.0/25"
    region = config.get("region")
    if region is None:
        region = "cn-hangzhou"
    tr_attachment_slave_cidr = config.get("trAttachmentSlaveCidr")
    if tr_attachment_slave_cidr is None:
        tr_attachment_slave_cidr = "192.168.3.128/26"
    firewall_vpc_cidr = config.get("firewallVpcCidr")
    if firewall_vpc_cidr is None:
        firewall_vpc_cidr = "192.168.3.0/24"
    zone1 = config.get("zone1")
    if zone1 is None:
        zone1 = "cn-hangzhou-h"
    firewall_name_update = config.get("firewallNameUpdate")
    if firewall_name_update is None:
        firewall_name_update = "tf-example-1"
    zone2 = config.get("zone2")
    if zone2 is None:
        zone2 = "cn-hangzhou-i"
    cen = alicloud.cen.Instance("cen",
        description="terraform example",
        cen_instance_name="Cen_Terraform_example01")
    tr = alicloud.cen.TransitRouter("tr",
        support_multicast=False,
        transit_router_name="CEN_TR_Terraform",
        transit_router_description="tr-created-by-terraform",
        cen_id=cen.id)
    vpc1 = alicloud.vpc.Network("vpc1",
        description="created by terraform",
        cidr_block="192.168.1.0/24",
        vpc_name="vpc1-Terraform")
    vpc1vsw1 = alicloud.vpc.Switch("vpc1vsw1",
        cidr_block="192.168.1.0/25",
        vswitch_name="vpc1-vsw1",
        vpc_id=vpc1.id,
        zone_id=zone1)
    vpc1vsw2 = alicloud.vpc.Switch("vpc1vsw2",
        vpc_id=vpc1.id,
        cidr_block="192.168.1.128/26",
        vswitch_name="vpc1-vsw2",
        zone_id=zone2)
    vpc2 = alicloud.vpc.Network("vpc2",
        description="created by terraform",
        cidr_block="192.168.2.0/24",
        vpc_name="vpc2-Terraform")
    vpc2vsw1 = alicloud.vpc.Switch("vpc2vsw1",
        cidr_block="192.168.2.0/25",
        vswitch_name="vpc2-vsw1",
        vpc_id=vpc2.id,
        zone_id=zone1)
    vpc2vsw2 = alicloud.vpc.Switch("vpc2vsw2",
        cidr_block="192.168.2.128/26",
        vswitch_name="vpc2-vsw2",
        vpc_id=vpc2.id,
        zone_id=zone2)
    tr_vpc1 = alicloud.cen.TransitRouterVpcAttachment("tr-vpc1",
        auto_publish_route_enabled=False,
        zone_mappings=[
            {
                "vswitch_id": vpc1vsw1.id,
                "zone_id": vpc1vsw1.zone_id,
            },
            {
                "zone_id": vpc1vsw2.zone_id,
                "vswitch_id": vpc1vsw2.id,
            },
        ],
        vpc_id=vpc1.id,
        cen_id=cen.id)
    tr_vpc2 = alicloud.cen.TransitRouterVpcAttachment("tr-vpc2",
        auto_publish_route_enabled=False,
        vpc_id=vpc2.id,
        zone_mappings=[
            {
                "vswitch_id": vpc2vsw1.id,
                "zone_id": vpc2vsw1.zone_id,
            },
            {
                "vswitch_id": vpc2vsw2.id,
                "zone_id": vpc2vsw2.zone_id,
            },
        ],
        cen_id=cen.id)
    default_vpc_cen_tr_firewall = alicloud.cloudfirewall.VpcCenTrFirewall("default",
        firewall_description="VpcCenTrFirewall created by terraform",
        region_no=region,
        route_mode="managed",
        cen_id=cen.id,
        firewall_vpc_cidr=firewall_vpc_cidr,
        transit_router_id=tr.transit_router_id,
        tr_attachment_master_cidr=tr_attachment_master_cidr,
        firewall_name=firewall_name,
        firewall_subnet_cidr=firewall_subnet_cidr,
        tr_attachment_slave_cidr=tr_attachment_slave_cidr)
    default = alicloud.cloudfirewall.get_vpc_cen_tr_firewalls_output(ids=[default_vpc_cen_tr_firewall.id],
        cen_id=cen.id,
        firewall_name=firewall_name,
        region_no=region,
        route_mode="managed",
        transit_router_id=tr.transit_router_id)
    pulumi.export("alicloudCloudFirewallVpcCenTrFirewallExampleId", default.firewalls[0].id)
    ```


    :param builtins.str cen_id: The ID of the CEN instance.
    :param builtins.int current_page: The page number of the pagination query. The default value is 1.
    :param builtins.str firewall_id: Firewall ID
    :param builtins.str firewall_name: The name of Cloud Firewall.
    :param builtins.str firewall_switch_status: The status of the VPC boundary firewall. Value:-**opened**: opened-**closed**: closed-**notconfigured**: indicates that the VPC boundary firewall has not been configured yet.-**configured**: indicates that the VPC boundary firewall has been configured.-**creating**: indicates that a VPC boundary firewall is being created.-**opening**: indicates that the VPC border firewall is being enabled.-**deleting**: indicates that the VPC boundary firewall is being deleted.> If this parameter is not set, the VPC boundary firewall in all states is queried.
    :param Sequence[builtins.str] ids: A list of Vpc Cen Tr Firewall IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Current page number.
    :param builtins.int page_size: The maximum number of pieces of data per page that are displayed during a paged query. The default value is 10.
    :param builtins.str region_no: The region ID of the transit router instance.
    :param builtins.str route_mode: The routing pattern. Value: managed: indicates automatic mode
    :param builtins.str transit_router_id: The ID of the transit router instance.
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['currentPage'] = current_page
    __args__['firewallId'] = firewall_id
    __args__['firewallName'] = firewall_name
    __args__['firewallSwitchStatus'] = firewall_switch_status
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['regionNo'] = region_no
    __args__['routeMode'] = route_mode
    __args__['transitRouterId'] = transit_router_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cloudfirewall/getVpcCenTrFirewalls:getVpcCenTrFirewalls', __args__, opts=opts, typ=GetVpcCenTrFirewallsResult)
    return __ret__.apply(lambda __response__: GetVpcCenTrFirewallsResult(
        cen_id=pulumi.get(__response__, 'cen_id'),
        current_page=pulumi.get(__response__, 'current_page'),
        firewall_id=pulumi.get(__response__, 'firewall_id'),
        firewall_name=pulumi.get(__response__, 'firewall_name'),
        firewall_switch_status=pulumi.get(__response__, 'firewall_switch_status'),
        firewalls=pulumi.get(__response__, 'firewalls'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        region_no=pulumi.get(__response__, 'region_no'),
        route_mode=pulumi.get(__response__, 'route_mode'),
        transit_router_id=pulumi.get(__response__, 'transit_router_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccountDmlAuthSetting',
    'ClickHouseEnterpriseDbClusterMultiZone',
]

@pulumi.output_type
class AccountDmlAuthSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ddlAuthority":
            suggest = "ddl_authority"
        elif key == "dmlAuthority":
            suggest = "dml_authority"
        elif key == "allowDatabases":
            suggest = "allow_databases"
        elif key == "allowDictionaries":
            suggest = "allow_dictionaries"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AccountDmlAuthSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AccountDmlAuthSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AccountDmlAuthSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ddl_authority: builtins.bool,
                 dml_authority: builtins.int,
                 allow_databases: Optional[Sequence[builtins.str]] = None,
                 allow_dictionaries: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.bool ddl_authority: Whether to grant the DDL permission to the database account. Value description:
        :param builtins.int dml_authority: Whether to grant the DML permission to the database account. The values are as follows:
        :param Sequence[builtins.str] allow_databases: The list of databases that require authorization. If there are more than one, separate them with commas (,).
        :param Sequence[builtins.str] allow_dictionaries: List of dictionaries that require authorization. If there are more than one, separate them with commas (,).
        """
        pulumi.set(__self__, "ddl_authority", ddl_authority)
        pulumi.set(__self__, "dml_authority", dml_authority)
        if allow_databases is not None:
            pulumi.set(__self__, "allow_databases", allow_databases)
        if allow_dictionaries is not None:
            pulumi.set(__self__, "allow_dictionaries", allow_dictionaries)

    @property
    @pulumi.getter(name="ddlAuthority")
    def ddl_authority(self) -> builtins.bool:
        """
        Whether to grant the DDL permission to the database account. Value description:
        """
        return pulumi.get(self, "ddl_authority")

    @property
    @pulumi.getter(name="dmlAuthority")
    def dml_authority(self) -> builtins.int:
        """
        Whether to grant the DML permission to the database account. The values are as follows:
        """
        return pulumi.get(self, "dml_authority")

    @property
    @pulumi.getter(name="allowDatabases")
    def allow_databases(self) -> Optional[Sequence[builtins.str]]:
        """
        The list of databases that require authorization. If there are more than one, separate them with commas (,).
        """
        return pulumi.get(self, "allow_databases")

    @property
    @pulumi.getter(name="allowDictionaries")
    def allow_dictionaries(self) -> Optional[Sequence[builtins.str]]:
        """
        List of dictionaries that require authorization. If there are more than one, separate them with commas (,).
        """
        return pulumi.get(self, "allow_dictionaries")


@pulumi.output_type
class ClickHouseEnterpriseDbClusterMultiZone(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "vswitchIds":
            suggest = "vswitch_ids"
        elif key == "zoneId":
            suggest = "zone_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClickHouseEnterpriseDbClusterMultiZone. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClickHouseEnterpriseDbClusterMultiZone.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClickHouseEnterpriseDbClusterMultiZone.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 vswitch_ids: Optional[Sequence[builtins.str]] = None,
                 zone_id: Optional[builtins.str] = None):
        """
        :param Sequence[builtins.str] vswitch_ids: The vSwtichID list.
        :param builtins.str zone_id: The zone ID.
        """
        if vswitch_ids is not None:
            pulumi.set(__self__, "vswitch_ids", vswitch_ids)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="vswitchIds")
    def vswitch_ids(self) -> Optional[Sequence[builtins.str]]:
        """
        The vSwtichID list.
        """
        return pulumi.get(self, "vswitch_ids")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[builtins.str]:
        """
        The zone ID.
        """
        return pulumi.get(self, "zone_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetOidcProvidersResult',
    'AwaitableGetOidcProvidersResult',
    'get_oidc_providers',
    'get_oidc_providers_output',
]

@pulumi.output_type
class GetOidcProvidersResult:
    """
    A collection of values returned by getOidcProviders.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, providers=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if providers and not isinstance(providers, list):
            raise TypeError("Expected argument 'providers' to be a list")
        pulumi.set(__self__, "providers", providers)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Oidc Provider IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of name of Oidc Providers.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def providers(self) -> Sequence['outputs.GetOidcProvidersProviderResult']:
        """
        A list of Oidc Provider Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "providers")


class AwaitableGetOidcProvidersResult(GetOidcProvidersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOidcProvidersResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            providers=self.providers)


def get_oidc_providers(ids: Optional[Sequence[builtins.str]] = None,
                       name_regex: Optional[builtins.str] = None,
                       output_file: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOidcProvidersResult:
    """
    This data source provides Ims Oidc Provider available to the user.[What is Oidc Provider](https://next.api.alibabacloud.com/document/Ims/2019-08-15/CreateOIDCProvider)

    > **NOTE:** Available since v1.248.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    oidc_provider_name = config.get("oidcProviderName")
    if oidc_provider_name is None:
        oidc_provider_name = "amp-resource-example-oidc-provider"
    default_oidc_provider = alicloud.ims.OidcProvider("default",
        description=oidc_provider_name,
        issuer_url="https://oauth.aliyun.com",
        fingerprints=["0BBFAB97059595E8D1EC48E89EB8657C0E5AAE71"],
        issuance_limit_time=12,
        oidc_provider_name=oidc_provider_name,
        client_ids=[
            "123",
            "456",
        ])
    default = alicloud.ims.get_oidc_providers_output(ids=[default_oidc_provider.id])
    pulumi.export("alicloudImsOidcProviderExampleId", default.providers[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Oidc Provider IDs.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ims/getOidcProviders:getOidcProviders', __args__, opts=opts, typ=GetOidcProvidersResult).value

    return AwaitableGetOidcProvidersResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        providers=pulumi.get(__ret__, 'providers'))
def get_oidc_providers_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                              name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOidcProvidersResult]:
    """
    This data source provides Ims Oidc Provider available to the user.[What is Oidc Provider](https://next.api.alibabacloud.com/document/Ims/2019-08-15/CreateOIDCProvider)

    > **NOTE:** Available since v1.248.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    oidc_provider_name = config.get("oidcProviderName")
    if oidc_provider_name is None:
        oidc_provider_name = "amp-resource-example-oidc-provider"
    default_oidc_provider = alicloud.ims.OidcProvider("default",
        description=oidc_provider_name,
        issuer_url="https://oauth.aliyun.com",
        fingerprints=["0BBFAB97059595E8D1EC48E89EB8657C0E5AAE71"],
        issuance_limit_time=12,
        oidc_provider_name=oidc_provider_name,
        client_ids=[
            "123",
            "456",
        ])
    default = alicloud.ims.get_oidc_providers_output(ids=[default_oidc_provider.id])
    pulumi.export("alicloudImsOidcProviderExampleId", default.providers[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Oidc Provider IDs.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ims/getOidcProviders:getOidcProviders', __args__, opts=opts, typ=GetOidcProvidersResult)
    return __ret__.apply(lambda __response__: GetOidcProvidersResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        providers=pulumi.get(__response__, 'providers')))
